==> localnews-user-service-1.0.3-sources.jar: com/bxm/localnews/user/service/impl/UserHobbyServiceImpl.java <==
package com.bxm.localnews.user.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import javax.annotation.Resource;

import com.bxm.localnews.user.domain.HobbyMapper;
import com.bxm.localnews.user.domain.UserHobbyMapper;
import com.bxm.localnews.user.service.UserHobbyService;
import com.bxm.localnews.user.vo.Hobby;
import com.bxm.localnews.user.vo.UserHobby;
import com.bxm.newidea.component.service.BaseService;

import org.apache.commons.lang3.ArrayUtils;
import org.springframework.stereotype.Service;

/**
 * Created by mars on 2018/3/15.
 */
@Service("userHobbyService")
public class UserHobbyServiceImpl extends BaseService implements UserHobbyService {

    @Resource
    private UserHobbyMapper userHobbyMapper;

    @Resource
    private HobbyMapper hobbyMapper;

    @Override
    public List<Hobby> listHobby() {
        return hobbyMapper.selectByModel(new Hobby());
    }

    @Override
    public List<UserHobby> listUserHobby(Long userId) {
        UserHobby userHobbyParam = new UserHobby();
        userHobbyParam.setUserId(userId);
        List<Hobby> hobbyList = hobbyMapper.selectByModel(new Hobby());
        List<UserHobby> userHobbyList = userHobbyMapper.selectByModel(userHobbyParam);

        List<UserHobby> userHobbyConvertList = hobbyList.stream().map(this::convertUserHobby).collect(Collectors.toList());
        List<UserHobby> resultHobbyList = new ArrayList<>();
        userHobbyConvertList.forEach(hobby->{
            if(userHobbyList.stream().anyMatch(userHobby -> userHobby.getName().equals(hobby.getName()))){
                hobby.setIsDefault((byte) 1);
            }
            resultHobbyList.add(hobby);
        });


        return resultHobbyList;
    }

    private UserHobby convertUserHobby(Hobby hobby){
        UserHobby userHobby = new UserHobby();
        userHobby.setName(hobby.getName());
        userHobby.setIsDefault((byte) 0);
        userHobby.setSortNo(hobby.getSortNo());
        return userHobby;
    }


    @Override
    public void saveUserHooby(Long userId, String[] names) {
        this.userHobbyMapper.deleteByUserId(userId);

        if (ArrayUtils.isNotEmpty(names)) {
            List<UserHobby> userHobbyList = new ArrayList<>();
            for (int i = 0; i < names.length; i++) {
                UserHobby userHobby = new UserHobby();
                userHobby.setUserId(userId);
                userHobby.setName(names[i]);
                userHobby.setSortNo(i);
                userHobby.setId(nextSequence());
                userHobbyList.add(userHobby);
            }

            this.userHobbyMapper.batchInsert(userHobbyList);
        }
    }
}

==> localnews-user-service-1.0.8-sources.jar: com/bxm/localnews/user/service/impl/UserHobbyServiceImpl.java <==
package com.bxm.localnews.user.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import javax.annotation.Resource;

import com.bxm.localnews.user.domain.HobbyMapper;
import com.bxm.localnews.user.domain.UserHobbyMapper;
import com.bxm.localnews.user.service.UserHobbyService;
import com.bxm.localnews.user.vo.Hobby;
import com.bxm.localnews.user.vo.UserHobby;
import com.bxm.newidea.component.service.BaseService;

import org.apache.commons.lang3.ArrayUtils;
import org.springframework.stereotype.Service;

/**
 * Created by mars on 2018/3/15.
 */
@Service("userHobbyService")
public class UserHobbyServiceImpl extends BaseService implements UserHobbyService {

    @Resource
    private UserHobbyMapper userHobbyMapper;

    @Resource
    private HobbyMapper hobbyMapper;

    @Override
    public List<Hobby> listHobby() {
        return hobbyMapper.selectByModel(new Hobby());
    }

    @Override
    public List<UserHobby> listUserHobby(Long userId) {
        UserHobby userHobbyParam = new UserHobby();
        userHobbyParam.setUserId(userId);
        List<Hobby> hobbyList = hobbyMapper.selectByModel(new Hobby());
        List<UserHobby> userHobbyList = userHobbyMapper.selectByModel(userHobbyParam);

        List<UserHobby> userHobbyConvertList = hobbyList.stream().map(this::convertUserHobby).collect(Collectors.toList());
        List<UserHobby> resultHobbyList = new ArrayList<>();
        userHobbyConvertList.forEach(hobby -> {
            if (userHobbyList.stream().anyMatch(userHobby -> userHobby.getName().equals(hobby.getName()))) {
                hobby.setIsDefault((byte) 1);
            }
            resultHobbyList.add(hobby);
        });


        return resultHobbyList;
    }

    private UserHobby convertUserHobby(Hobby hobby) {
        UserHobby userHobby = new UserHobby();
        userHobby.setName(hobby.getName());
        userHobby.setIsDefault((byte) 0);
        userHobby.setSortNo(hobby.getSortNo());
        return userHobby;
    }

    @Override
    public void saveUserHobby(Long userId, String[] names) {
        this.userHobbyMapper.deleteByUserId(userId);

        if (ArrayUtils.isNotEmpty(names)) {
            List<UserHobby> userHobbyList = new ArrayList<>();
            for (int i = 0; i < names.length; i++) {
                UserHobby userHobby = new UserHobby();
                userHobby.setUserId(userId);
                userHobby.setName(names[i]);
                userHobby.setSortNo(i);
                userHobby.setId(nextSequence());
                userHobbyList.add(userHobby);
            }

            this.userHobbyMapper.batchInsert(userHobbyList);
        }
    }
}
